@@ -1,7 +1,7 @@
-__version__ = "0.1.11"
+__version__ = "0.1.143"
 __author__ = u"Artap Team"
 __author_email__ = "artap.team@gmail.com"
 __copyright__ = u"Copyright (c) 2018-2019, {} <{}>".format(__author__, __author_email__)
-__website__ = "https://edison.fel.zcu.cz:444/agros/RDOLab/Artap"
+__website__ = "http://agros2d.org/artap"
 __license__ = "License :: OSI Approved :: MIT License"
 __status__ = "Development Status :: 3 - Alpha"
