@@ -2,7 +2,8 @@ from .problem import Problem
 from .utils import ConfigDictionary
 from .job import JobSimple
 from .population import Population
-from .individual import Individual
+from .individual import Individual,GeneticIndividual
+from .operators import RandomGeneration
 
 from abc import ABCMeta, abstractmethod
 import numpy as np
@@ -30,6 +31,10 @@ class Algorithm(metaclass=ABCMeta):
         # initial population size
         self.population_size = 0
 
+        # set random generator
+        self.generator = RandomGeneration(self.problem.parameters)
+        self.generator.init(10)
+
     @abstractmethod
     def run(self):
         pass
@@ -52,11 +57,15 @@ class Algorithm(metaclass=ABCMeta):
             self.evaluate_parallel(individuals)
         else:
             self.evaluate_serial(individuals)
+
         n_failed = 0
         for individual in individuals:
             if individual.state == Individual.State.FAILED:
                 n_failed += 1
-                individuals.remove(individual)
+                individuals.remove(individual)   # TODO: is can be not feasible?
+            if isinstance(individual, GeneticIndividual):
+                individual.transform_data(self.problem.signs)
+
 
     def evaluate_serial(self, individuals: list):
         job = JobSimple(self.problem)
@@ -70,49 +79,6 @@ class Algorithm(metaclass=ABCMeta):
         Parallel(n_jobs=self.options["max_processes"], verbose=1, require='sharedmem')(delayed(job.evaluate)(individual)
                                                                                        for individual in individuals)
 
-
-
-        """
-        manager = Manager()
-        processes = []
-        i = 0
-        n = len(individuals)
-        while i < n:
-            j = 0
-            shared_list = manager.list([])
-            queue = Queue()
-            job = JobQueue(self.problem, shared_list, queue)
-            while (j < self.options["max_processes"]) and ((i + j) < n):
-                individual = individuals[i + j]
-                if not individual.is_evaluated:
-                    p = Process(target=job.evaluate, args=(individual,))
-                    processes.append(p)
-                    p.start()
-                    shared_list.append([p.pid, individual])
-                # increment index
-                j += 1
-
-            for process in processes:
-                process.join()
-
-            processes = []
-            i += j
-
-            for item in range(queue.qsize()):
-                local_individual = queue.get()
-                # TODO: rewrite !!! - very slow
-                for individual in individuals:
-                    if local_individual.vector == individual.vector:
-                        # update individual
-                        individual.sync(local_individual)
-
-                        # write to datastore
-                        if self.problem.options["save_level"] == "individual":
-                            self.problem.data_store.write_individual(individual)
-            queue.close()
-            queue.join_thread()
-        """
-
     def evaluate_gradient(self, individuals: list, gradient_individuals: list):
         # Todo: Make operator Gradient consisting of current gradient generator and evaluate_gradient
         # individuals.sort(key=lambda x: abs(x.depends_on))
