@@ -1,12 +1,12 @@
 from .problem import Problem
 from .algorithm import Algorithm
-from .environment import Enviroment
+from .config import artap_root
 from .job import JobSimple
 
 import time
 
 import sys
-sys.path.append(Enviroment.artap_root + "/lib/")
+sys.path.append(artap_root + "/lib/")
 
 import _nlopt
 
@@ -533,7 +533,6 @@ class NLopt(Algorithm):
     def __init__(self, problem: Problem, name="NLopt"):
         super().__init__(problem, name)
 
-        self.problem.options['save_level'] = 'individual'
         self.job = JobSimple(self.problem)
         self.options.declare(name='algorithm', default=LN_BOBYQA, values=_algorithm,
                              desc='Algorithm')
