@@ -3,10 +3,12 @@ import sys
 import random
 import math
 import itertools
-
+import numpy as np
+from math import exp
 from .individual import Individual
 from .utils import VectorAndNumbers
 from .doe import build_box_behnken, build_lhs, build_full_fact, build_plackett_burman
+from copy import copy
 
 EPSILON = sys.float_info.epsilon
 
@@ -23,15 +25,12 @@ class Operation(ABC):
 
 class Generation(Operation):
 
-    def __init__(self, problem=None, individual_class=Individual, parameters=None):
+    def __init__(self, parameters=None, individual_class=Individual):
         super().__init__()
-        if problem is not None:
-            self.parameters = problem.parameters
-        else:
-            self.parameters = parameters
+        self.parameters = parameters
         self.individual_class = individual_class
 
-    def create_individual(self, vector: list=[]):
+    def create_individual(self, vector: list = []):
         return self.individual_class(vector)
 
     @abstractmethod
@@ -41,8 +40,8 @@ class Generation(Operation):
 
 class CustomGeneration(Generation):
 
-    def __init__(self, problem=None):
-        super().__init__(problem)
+    def __init__(self, parameters=None, individual_class=Individual):
+        super().__init__(parameters, individual_class)
         self.vectors = []
 
     def init(self, vectors):
@@ -57,8 +56,8 @@ class CustomGeneration(Generation):
 
 class RandomGeneration(Generation):
 
-    def __init__(self, problem=None, individual_class=Individual, parameters=None):
-        super().__init__(problem, individual_class, parameters=parameters)
+    def __init__(self, parameters=None, individual_class=Individual):
+        super().__init__(parameters, individual_class)
         self.number = 0
 
     def init(self, number):
@@ -78,8 +77,8 @@ class FullFactorGeneration(Generation):
     Number of experiments (2 ** len(parameters) - without center, 3 ** len(parameters - with center)
     """
 
-    def __init__(self, problem=None, parameters=None):
-        super().__init__(problem, parameters=parameters)
+    def __init__(self, parameters=None, individual_class=Individual):
+        super().__init__(parameters, individual_class)
         self.center = False
 
     def init(self, center):
@@ -111,8 +110,8 @@ class PlackettBurmanGeneration(Generation):
     Number of experiments (2 ** len(parameters) - without center, 3 ** len(parameters - with center)
     """
 
-    def __init__(self, problem=None, parameters=None):
-        super().__init__(problem, parameters=parameters)
+    def __init__(self, parameters=None, individual_class=Individual):
+        super().__init__(parameters, individual_class)
 
     def generate(self):
         dict_vars = {}
@@ -143,8 +142,8 @@ class BoxBehnkenGeneration(Generation):
     https://en.wikipedia.org/wiki/Box%E2%80%93Behnken_design
     """
 
-    def __init__(self, problem=None, parameters=None):
-        super().__init__(problem, parameters=parameters)
+    def __init__(self, parameters=None, individual_class=Individual):
+        super().__init__(parameters, individual_class, )
 
     def generate(self):
         dict_vars = {}
@@ -168,8 +167,8 @@ class LHSGeneration(Generation):
     Builds a Latin Hypercube design dataframe from a dictionary of factor/level ranges.
     """
 
-    def __init__(self, problem=None, parameters=None):
-        super().__init__(problem, parameters=parameters)
+    def __init__(self, parameters=None, individual_class=Individual):
+        super().__init__(parameters, individual_class)
         self.number = 0
 
     def init(self, number):
@@ -194,8 +193,8 @@ class LHSGeneration(Generation):
 
 class GradientGeneration(Generation):
 
-    def __init__(self, problem=None, parameters=None):
-        super().__init__(parameters=parameters)
+    def __init__(self, parameters=None, individual_class=Individual):
+        super().__init__(parameters, individual_class)
         self.delta = 1e-6
         self.individuals = None
 
@@ -317,9 +316,9 @@ class PmMutation(Mutation):
 
         return x
 
-    def bitflip(self, x:list):
+    def bitflip(self, x: list):
 
-        for j in range(1,len(x)):
+        for j in range(1, len(x)):
             if random.uniform(0.0, 1.0) <= self.probability:
                 x[j] = not x[j]
 
@@ -327,17 +326,27 @@ class PmMutation(Mutation):
 
 
 class SwarmMutation(Mutation):
+    """
+    This swarm mutator operator is made for the original PSO algorithm, which defined by Kennedy and Eberhart in 1995
+
+    PSO shares many similarities with evolutionary computation. Both algorithms start with a group of a randomly
+    generated population. Both update the population iteratively and search for the optimum with stochastic techniques.
+    The main difference between them is in the information sharing mechanism. In EA, only the individuals of current
+    generation share information with each other, and any individual has a chance to give out information to others.
+    In PSO, actually not the current individuals share information with each other, but the individuals of previous
+    generation (the optimal particles) give out information to the current ones. In other words, the information sharing
+    is one-way in PSO.
+    """
 
     def __init__(self, parameters, probability=1):
         super().__init__(parameters, probability)
         self.w = 0.1  # constant inertia weight (how much to weigh the previous velocity)
-        self.c1 = 2  # cognitive constant
-        self.c2 = 1  # social constant
+        self.c1 = 2.  # cognitive constant
+        self.c2 = 1.  # social constant
         self.best_individual = None
 
-    # evaluate current fitness
-    def evaluate_pso(self, individual):
-
+    def evaluate_best_individual(self, individual):
+        """ Determines the best individual in the swarm """
         dominates = True
 
         for i in range(len(individual.best_costs)):
@@ -353,7 +362,6 @@ class SwarmMutation(Mutation):
     def update_velocity(self, individual):
 
         for i in range(0, len(individual.vector)):
-
             r1 = 0.1 * random.random()
             r2 = 0.1 * random.random()
 
@@ -384,12 +392,289 @@ class SwarmMutation(Mutation):
         return p
 
 
+class SwarmMutationTVIW(SwarmMutation):
+    """
+    This is an improvement of the original PSO algorithm with Time Varying Inertia Weight operators.
+
+    Empirical study of particle swarm optimization,” in Proc. IEEE Int. Congr. Evolutionary Computation, vol. 3,
+    1999, pp. 101–106.
+
+    Shi and Eberhart have observed that the optimal solution can be improved by varying the inertia weight value from
+    0.9 (at the beginning of the search) to 0.4 (at the end of the search) for most problems. This modification to the
+    original PSO concept has been considered as the basis for two novel strategies introduced in this paper. Hereafter,
+    in this paper, this version of PSO is referred to as time-varying inertia weight factor method
+
+    Contras:
+    -------
+    - PSO-TVIW concept is not very effective for tracking dynamic systems
+
+    - its ability to fine tune the optimum solution is comparatively weak, mainly due
+      to the lack of diversity at the end of the search
+
+    R. C. Eberhart and Y. Shi, “Tracking and optimizing dynamic systems with particle swarms,” in Proc. IEEE Congr.
+    Evolutionary Computation 2001, Seoul, Korea, 2001, pp. 94–97
+    """
+
+    def __init__(self, parameters, probability=1, nr_maxgen=100):
+        super().__init__(parameters, probability)
+        self.w1 = 0.9  # inertia weight is calculated from w1 and w2
+        self.w2 = 0.4
+        self.c1 = 2.  # cognitive constant
+        self.c2 = 1.  # social constant
+        self.best_individual = None
+
+        # new parameters
+        self.max_nr_generations = nr_maxgen
+        self.current_iter = 0.
+
+    # update new particle velocity
+    def update_velocity(self, individual):
+        """
+        :param nr_generations: total number of generations, during the calculation, MAXITER
+        :param iteration_nr: actual generation
+        """
+        for i in range(0, len(individual.vector)):
+            r1 = 0.1 * random.random()
+            r2 = 0.1 * random.random()
+
+            # (w1-w2)*(MAX_ITER-iter)/MAX_ITER
+            w = (self.w1 - self.w2) * (self.max_nr_generations - self.current_iter) / self.max_nr_generations + self.w2
+
+            vel_cognitive = self.c1 * r1 * (individual.best_vector[i] - individual.vector[i])
+            vel_social = self.c2 * r2 * (self.best_individual.vector[i] - individual.vector[i])
+            individual.velocity_i[i] = w * individual.velocity_i[i] + vel_cognitive + vel_social
+
+            self.current_iter += 1.
+
+
+class SwarmMutationRandIW(SwarmMutation):
+    """
+    In this variation, the inertia weght is changing randomly,the mean value of the inertia weight is 0.75.
+    This modification was inspired by Clerc’s constriction factor concept,  in which the inertia weight is
+    kept constant at 0.729 and both acceleration coefficients are kept constant at 1.494.
+    Therefore, when random inertia weight factor method is used the acceleration coefficients are kept constant at 1.494.
+
+    Contras:
+    -------
+    """
+
+    def __init__(self, parameters, probability=1):
+        super().__init__(parameters, probability)
+        self.w = 0.5  # inertia weight -> changed randomly
+        self.c1 = 2.  # cognitive constant
+        self.c2 = 1.  # social constant
+        self.best_individual = None
+
+    # update new particle velocity
+    def update_velocity(self, individual):
+        """
+        :param nr_generations: total number of generations, during the calculation, MAXITER
+        :param iteration_nr: actual generation
+        """
+        for i in range(0, len(individual.vector)):
+            r1 = 0.1 * random.random()
+            r2 = 0.1 * random.random()
+
+            # (w1-w2)*(MAX_ITER-iter)/MAX_ITER
+            w = self.w * random.random() / 2.
+
+            vel_cognitive = self.c1 * r1 * (individual.best_vector[i] - individual.vector[i])
+            vel_social = self.c2 * r2 * (self.best_individual.vector[i] - individual.vector[i])
+            individual.velocity_i[i] = w * individual.velocity_i[i] + vel_cognitive + vel_social
+
+
+class FireflyMutation(SwarmMutation):
+    """
+    Firefly algorithm is a modification of the original pso algorithms. The idea is that it mimics the behaviour of
+    the fireflies, which uses specfic light combinations for hunting and dating. This algorithm mimics the dating
+    behaviour of these bugs. The algorithm is originally published by [1]
+
+    The brightest individual attracts the darkest ones, this starts to go to that direction, if there is not an
+    existing brighter solutions, the algorithm randomly steps one into another direction.
+
+    This operator makes the following
+    ---------------------------------
+
+    - calculates the distance between two points, because its correlates with that value.
+    - the brightness of the other point
+    - the mutator constant, which contains a damping factor [2]?
+
+    The k+1 th position of the j(th) individual is calculated by the following formula
+    ---------------------------------------------------------------------------
+
+        b0=2;               # Attraction Coefficient Base Value
+        a=0.2;              # Mutation Coefficient
+        ad=0.98;            # Mutation Coefficient Damping Ratio -- decreases the initial value of a after each
+                              iteration step
+        gamma = 1.          # light absorbtion coefficient
+
+        x(j,k+1) = x(j,k) + b0*exp(-gamma*r^2) + sum_{i<j}[x(j,k) - x(i,k)] + a*(rand[0,1] - 0.5)
+
+    [1] Yang, Xin-She. "Firefly algorithms for multimodal optimization." International symposium on stochastic algorithms.
+        Springer, Berlin, Heidelberg, 2009.
+    [2] firefly algorithm implementation from www.Yarpiz.com
+
+    [3] https://nl.mathworks.com/matlabcentral/fileexchange/29693-firefly-algorithm
+
+     Similarly, alpha should also be linked with scales, the steps should not too large or too small, often steps
+     are about 1/10 to 1/100 of the domain size. In addition, alpha should be reduced gradually using
+     alpha=alpha_0 delta^t during eteration t.  Typically, delta=0.9 to 0.99 will be a good choice.
+    """
+
+    def __init__(self, parameters, probability=0.05):
+        super().__init__(parameters, probability)
+
+        self.beta = 2.0
+        self.alpha = 0.2
+        self.ad = 0.98
+        self.gamma = 1.
+
+        self.best_individual = None
+
+    def dominate(self, current, other):
+        """True if other dominates over current """
+        dominates = True
+
+        for i in range(len(current.costs)):
+            if other.signed_costs[i] > current.signed_costs[i]:
+                dominates = False
+
+        return dominates
+
+    def update_coefficient_a(self):
+        """ Updates the mutation coefficient with the damping factor, after each iteration step """
+        self.alpha *= self.ad
+        return
+
+    # update new particle velocity
+    def update_velocity_ij(self, current, other):
+        """
+        This algorithm has a two-layered hierarchy, because every individual calculates an approximative next position
+        from the light intensity between two selected points.
+        """
+        r2 = 0.  # euclidean distance
+
+        for i, param in enumerate(self.parameters):
+
+            lb = param['bounds'][0]
+            ub = param['bounds'][1]
+
+            # elementary distance of the particle
+            e = self.probability * (ub - lb)
+            # distance between the two individuals
+            r2 += current.vector[i] ** 2. + other.vector[i] ** 2.
+            vel_attraction = self.beta * exp(-self.gamma * r2 ** 2.)
+
+            v_rd = self.alpha * (random.random() - 0.5) * e
+            current.velocity_i[i] = vel_attraction + v_rd
+
+            # for individual in offsprings:
+            #     for other in offsprings:
+            #         dominates = False
+            #
+            #         if individual is not other:
+            #             dominates = True
+            #
+            #         for i in range(len(individual.signed_costs)):
+            #             if individual.signed_costs[i] > offsprings.signed_costs[i]:
+            #                 dominates = False
+            #
+            #         if dominates:
+            #
+            #             r2 = 0
+            #             for i, param in enumerate(self.parameters):
+            #                 l_b = param['bounds'][0]
+            #                 u_b = param['bounds'][1]
+            #
+            #                 # elementary distance of the particle (to do not )
+            #                 e = self.probability*(u_b-l_b)
+            #                 # distance between the two individuals
+            #                 r2 += individual.vector[i]**2. + other.vector[i]**2.
+            #
+            #                 vel_attraction = self.beta*exp(-self.gamma*r2**2.)
+            #
+            #                 v_rd = self.alpha * (random.random() - 0.5) * e
+            #                 individual.velocity_i[i] = vel_attraction + v_rd
+            #
+            #                 temp = copy(individual)
+            #                 self.evaluate(temp)
+            #
+            #                 dom = True
+            #                 for j in range(len(individual.best_costs)):
+            #                     if individual.signed_costs[j] > offsprings.signed_costs[j]:
+            #                         dom = False
+            #
+            #                 if dom is True:
+            #                     individual = copy(temp)
+
+            return
+
+    def mutate_ij(self, p, q):
+        """
+        For firefly algorithm, because of the two-layered hierarchy.
+
+        :param p:
+        :param q:
+        :return:
+        """
+        self.update_velocity_ij(p,q)
+        self.update_position(p)
+        return
+
+
+class SwarmMutationTVAC(SwarmMutation):
+    """
+    Time-varying acceleration coefficients as a new parameter automation strategy for the PSO concept.
+
+    An improved optimum solution for most of the benchmarks was observed when changing c1 from 2.5 to 0.5
+    and changing c2 from 0.5 to 2.5, over the full range of the search.
+    Therefore, these values are used for the rest of the work. With this modification, a significant improvement of
+    the optimum value and the rate of convergence were observed, particularly for unimodal functions, compared with
+    the PSO-TVIW. However, it has been observed that the performance of the PSO-TVAC method is similar or poor
+    for multimodal functions. In contrast, compared with the PSO-RANDIW method an improved performance has been
+    observed with the PSO-TVAC for multimodal functions.
+    However, for unimodal functions, the PSO-RANDIW method showed significantly quick convergence to a good solution
+    compared with the PSO-TVAC method. The results are presented and discussed in Section V.
+
+    Pros: improved convergence rate in case of multi-modal functions
+
+    Cons: significantly slower convergence rate than PSO-RandIW for unimodal functions
+    """
+
+    def __init__(self, parameters, probability=1):
+        super().__init__(parameters, probability)
+        self.w = 0.9  # inertia weight
+        self.c1i = 0.5  # cognitive constant initial value
+        self.c1f = 2.5  # cognitive constant final value
+        self.c2i = 2.5  # social constant initial value
+        self.c2f = 0.5  # social constant final value
+        self.best_individual = None
+
+    # update new particle velocity
+    def update_velocity(self, individual, nr_generations, iteration_nr):
+        """
+        :param nr_generations: total number of generations, during the calculation, MAXITER
+        :param iteration_nr: actual generation
+        """
+        for i in range(0, len(individual.vector)):
+            r1 = 0.1 * random.random()
+            r2 = 0.1 * random.random()
+
+            # (c1f-c1i)*(MAX_ITER-iter)/MAX_ITER +
+            c1 = (self.c1f - self.c1i) * (nr_generations - iteration_nr) / nr_generations + self.c1i
+            c2 = (self.c2f - self.c2i) * (nr_generations - iteration_nr) / nr_generations + self.c2i
+
+            vel_cognitive = c1 * r1 * (individual.best_vector[i] - individual.vector[i])
+            vel_social = c2 * r2 * (self.best_individual.vector[i] - individual.vector[i])
+            individual.velocity_i[i] = self.w * individual.velocity_i[i] + vel_cognitive + vel_social
+
+
 class Selection(Operation):
 
-    def __init__(self, parameters, signs, part_num=2):
+    def __init__(self, parameters, part_num=2):
         super().__init__()
         self.parameters = parameters
-        self.signs = signs
+        # self.signs = signs
         self.part_num = part_num
         self.comparator = ParetoDominance()
 
@@ -425,7 +710,7 @@ class Selection(Operation):
             for q in population:
                 if p is q:
                     continue
-                if self.comparator.compare(p, q) == 1:          # TODO: simplify
+                if self.comparator.compare(p, q) == 1:  # TODO: simplify
                     p.dominate.add(q)
                 elif self.comparator.compare(q, p) == 1:
                     p.domination_counter = p.domination_counter + 1
@@ -477,7 +762,6 @@ class DummySelection(Selection):
     def select(self, individuals):
         selection = []
         for individual in individuals:
-
             candidate = individual.__class__(individual.vector)
             candidate.costs = individual.costs
             candidate.front_number = individual.front_number
@@ -506,7 +790,7 @@ class EpsilonDominance(Dominance):
         or the box is preferred.
     """
 
-    def __init__(self, epsilons, signs=None):
+    def __init__(self, epsilons):
         super(EpsilonDominance, self).__init__()
 
         if hasattr(epsilons, "__getitem__"):
@@ -515,7 +799,6 @@ class EpsilonDominance(Dominance):
             self.epsilons = [epsilons]
 
     def same_box(self, p, q):
-
         # first check constraint violation
         if p.feasible != q.feasible:
             if p.feasible == 0:
@@ -546,12 +829,10 @@ class EpsilonDominance(Dominance):
 
             if i1 < i2:
                 dominate1 = True
-
                 if dominate2:
                     return False
             elif i1 > i2:
                 dominate2 = True
-
                 if dominate1:
                     return False
 
@@ -561,7 +842,6 @@ class EpsilonDominance(Dominance):
             return False
 
     def compare(self, p, q):
-
         # first check constraint violation
         if p.feasible != q.feasible:
             if p.feasible == 0:
@@ -630,39 +910,98 @@ class ParetoDominance(Dominance):
     Pareto dominance is used to select the preferred solution.
     """
 
-    def __init__(self, signs, epsilons=None):
+    def __init__(self, epsilons=None):
         super(ParetoDominance, self).__init__()
-        self.signs = signs
+        # self.signs = signs deprecated
+
+    # @jit
+    def compare(self, p: list, q: list):
+        """
+        Here, p and q are tuples, which contains the (feasibility index, cost vector)
+        """
 
-    def compare(self, p, q):
-        if len(p.costs) != len(q.costs):
-            print("Len {} - {}".format(len(p.costs), len(p.costs)))
         # first check constraint violation
-        if p.feasible != q.feasible:
-            if p.feasible == 0:
+        if p[-1] != q[-1]:
+            if p[-1] == 0:
                 return 1
-            elif q.feasible == 0:
+            elif q[-1] == 0:
                 return 2
-            elif p.feasible < q.feasible:
+            elif p[-1] < q[0]:
                 return 1
-            elif q.feasible < p.feasible:
+            elif q[-1] < p[0]:
                 return 2
 
+        # if p.feasible != q.feasible:
+        #     if p.feasible == 0:
+        #         return 1
+        #     elif q.feasible == 0:
+        #         return 2
+        #     elif p.feasible < q.feasible:
+        #         return 1
+        #     elif q.feasible < p.feasible:
+        #         return 2
+
         # The cost function can be a float or a list of floats
         # Check the pareto dominance on every value of the calculated vectors
+
+        # numpy makes the calculation elementwise, so we are calculating the result vector at first
+        # and checks that is p can dominate q
+        # res = p>q
+        #
+        # dominate_p = False
+        # dominate_q = False
+        #
+        # for i in res[:-1]:
+        #     if i:
+        #         dominate_q = True
+        #         if dominate_p:
+        #             return 0
+        #     else:
+        #         dominate_p = True
+        #         if dominate_q:
+        #             return 0
+        #
+        # if dominate_p == dominate_q:
+        #     return 0
+        #
+        # elif dominate_p:
+        #     return 1
+        # else:
+        #     return 2
+
+        # the old solution
+        # dominate_p = False
+        # dominate_q = False
+        #
+        # for (p_costs, q_costs, sign) in zip(p.costs, q.costs, self.signs):
+        #
+        #     if sign * p_costs > sign * q_costs:
+        #         dominate_q = True
+        #         if dominate_p:
+        #             return 0
+        #     else:
+        #         dominate_p = True
+        #         if dominate_q:
+        #             return 0
+        #
+        # if dominate_q == dominate_p:
+        #     return 0
+        # elif dominate_p:
+        #     return 1
+        # else:
+        #     return 2
+
         dominate_p = False
         dominate_q = False
-        for i in range(0, len(p.costs)):
-            sign = self.signs[i]
-            if sign * p.costs[i] > sign * q.costs[i]:
-                dominate_q = True
 
+        for (p_costs, q_costs) in zip(p[:-1], q[:-1]):
+
+            if p_costs > q_costs:
+                dominate_q = True
                 if dominate_p:
                     return 0
-
-            if sign * p.costs[i] < sign * q.costs[i]:
+            else:
                 dominate_p = True
-
                 if dominate_q:
                     return 0
 
@@ -676,12 +1015,19 @@ class ParetoDominance(Dominance):
 
 class Selection(Operation):
 
-    def __init__(self, parameters, signs=None, part_num=2, dominance=ParetoDominance):
+    def __init__(self, parameters, sign=None, part_num=2, dominance=ParetoDominance):
+        """
+
+        :param parameters:
+        :param sign: one value from now, because its goal is to tell the direction of the optimum min or max
+        :param part_num:
+        :param dominance:
+        """
         super().__init__()
         self.parameters = parameters
         self.part_num = part_num
-        self.comparator = dominance(signs=signs)  # ParetoDominance()
-        self.signs = signs
+        self.comparator = dominance()  # ParetoDominance()
+        self.signs = sign
 
     @abstractmethod
     def select(self, population):
@@ -693,15 +1039,12 @@ class Selection(Operation):
         :param q: candidate
         :return: True if the candidate is better than the current solution
         """
-        dominate = False
-
         # The cost function can be a float or a list of floats
-        for i in range(0, len(p.costs)):
-            if p.costs[i] > q.costs[i]:
+        for p_costs, q_costs in zip(p.costs, q.costs):
+            if p_costs > q_costs:
                 return False
-            if p.costs[i] <= q.costs[i]:
-                dominate = True
-        return dominate
+            else:
+                return True
 
     def sorting(self, generation):
         """
@@ -720,10 +1063,9 @@ class Selection(Operation):
             for q in generation:
                 if p is q:
                     continue
-                if self.comparator.compare(p, q) == 1:          # TODO: simplify
+                if self.comparator.compare(p.signed_costs, q.signed_costs) == 1:  # TODO: simplify
                     p.dominate.add(q)
-                    p.dominate.add(q)
-                elif self.comparator.compare(q, p) == 1:
+                elif self.comparator.compare(q.signed_costs, p.signed_costs) == 1:
                     p.domination_counter += 1
 
             if p.domination_counter == 0:
@@ -768,13 +1110,12 @@ class Selection(Operation):
 
 class DummySelection(Selection):
 
-    def __init__(self, parameters, signs, part_num=2):
-        super().__init__(parameters, signs, part_num)
+    def __init__(self, parameters, sign, part_num=2):
+        super().__init__(parameters, sign, part_num)
 
     def select(self, individuals):
         selection = []
         for individual in individuals:
-
             candidate = individual.__class__(individual.vector)
             candidate.costs = individual.costs
             candidate.front_number = individual.front_number
@@ -787,10 +1128,10 @@ class DummySelection(Selection):
 
 class TournamentSelection(Selection):
 
-    def __init__(self, parameters, signs=None, dominance=ParetoDominance, epsilons=None):
-        super().__init__(parameters, signs=signs)
-        self.dominance = dominance(signs=signs, epsilons=epsilons)
-        self.signs = signs
+    def __init__(self, parameters, dominance=ParetoDominance, epsilons=None):
+        super().__init__(parameters)
+        self.dominance = dominance(epsilons=epsilons)
+        # self.signs = sign
         # self.dominance = EpsilonDominance([0.01])
 
     def select(self, population):
@@ -806,7 +1147,8 @@ class TournamentSelection(Selection):
 
         for _ in range(self.part_num - 1):
             candidate = random.choice(population)
-            flag = self.dominance.compare(winner, candidate)
+
+            flag = self.dominance.compare(winner.signed_costs, candidate.signed_costs)
 
             if flag > 0:
                 winner = candidate
